@@ -24,7 +24,7 @@ biggrid
 biggrid <- biggrid |>
     # for now only for 1000 years at very high tolerance so it's fast
     mutate(atol = 1e-4, tend = -1e3)
-    # this would be the real deal, the full 100--0 Ma results at medium
+    # this would be the real deal, the full 100--0 Myr results at medium
     # tolerance.
     ## mutate(tol = 1e-7, tend = -1e5)
 
@@ -67,11 +67,10 @@ expanded
 
 ## ----plot---------------------------------------------------------------------
 expanded |>
-  ggplot(aes(x = -t_ka, y = cp,
+  ggplot(aes(x = time, y = cp,
              colour = factor(Td),
              linetype = factor(Ed))) +
-  scale_x_reverse() +
-  labs(x = "Age (ka)",
+  labs(x = "Time (kyr)",
        y = "Climatic precession",
        colour = "Tidal dissipation",
        linetype = "Dynamical ellipticity") +
@@ -83,8 +82,8 @@ expanded |>
             linetype = "solid",
             colour = "black",
             data = get_solution() |>
-              filter(t_ka > -1000) |>
-              filter(t_ka < -500))
+              filter(time > -1000) |>
+              filter(time < -500))
 
 ## ----add-filenames------------------------------------------------------------
 biggrid <- biggrid |>
@@ -124,13 +123,12 @@ biggrid |> # limit to a few experiments
   # unfold the list column
   unnest(fullsol) |>
   # plot the obliquity
-  ggplot(aes(x = -t_ka, y = epl,
+  ggplot(aes(x = time, y = epl,
              colour = factor(Td),
              linetype = factor(Ed))) +
-  labs(x = "Age (ka)", y = "Obliquity",
+  labs(x = "Time (kyr)", y = "Obliquity",
        colour = "Tidal dissipation",
        linetype = "Dynamical ellipticity") +
-  scale_x_reverse() +
   ## facet_grid(rows = vars(Td)) +
   geom_line()
 
